@@ -12,7 +12,7 @@ from trexlib.utils.log_util import get_tracelog
 
 from trexlib.utils.google.bigquery_util import execute_query, process_job_result_into_category_and_count, create_bigquery_client
 
-logger = logging.getLogger('debug')
+logger = logging.getLogger('analytic')
 
 class QueryBaseResource(Resource):
     
@@ -22,11 +22,16 @@ class QueryBaseResource(Resource):
     def get(self):
         content         = request.json or request.args.to_dict() or {}
         query           = self.prepare_query(**content)
+        
+        logger.info('query=%s', query)
+        
         bg_client       = create_bigquery_client()
         job_result_rows = execute_query(bg_client, query)
         
         query_result    = self.process_query_result(job_result_rows)
         
+        logger.debug('query_result=%s', query_result)
+        
         return query_result
         
     def prepare_query(self, **kwrgs):
